"""
Tavix - Your AI-powered shell assistant and coding companion.

A powerful CLI tool that leverages Google's Gemini AI to transform your terminal experience.
"""

__version__ = "0.1.0"
__author__ = "Tavix Team"
__description__ = "AI-powered shell assistant and coding companion" 